AbrControllerMobile class

Implemented types

Constructors

AbrControllerMobile(String channelSuffix)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAbrStrategy() Future<AbrStrategyConfigurationInternal>
override
getPreferredPeakBitRate() Future<double>
override
getTargetBuffer() Future<double>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setAbrStrategy(AbrStrategyConfigurationInternal config) Future<void>
override
setPreferredPeakBitRate(double value) Future<void>
override
setTargetBuffer(double value) Future<void>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited