AbrInternalInterface class abstract

Internal interface for ABR configuration.

Implemented by platform-specific view controllers (web via JS interop, native via Pigeon bridge).

Implementers

Constructors

AbrInternalInterface()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAbrStrategy() Future<AbrStrategyConfigurationInternal>
getPreferredPeakBitRate() Future<double>
getTargetBuffer() Future<double>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setAbrStrategy(AbrStrategyConfigurationInternal config) Future<void>
setPreferredPeakBitRate(double value) Future<void>
setTargetBuffer(double value) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited