THEOplayerFlutterTextTracksAPI class abstract

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onAddTextTrack(String? id, int uid, String? label, String? language, String? kind, String? inBandMetadataTrackDispatchType, TextTrackReadyState readyState, TextTrackType type, String? source, bool isForced, TextTrackMode mode, String? unlocalizedLabel) → void
onCueEnter(int textTrackUid, int cueUid) → void
onCueExit(int textTrackUid, int cueUid) → void
onCueUpdate(int textTrackUid, int cueUid, double endTime, String content) → void
onRemoveTextTrack(int uid) → void
onTextTrackAddCue(int textTrackUid, String id, int uid, double startTime, double endTime, String content) → void
onTextTrackAddDateRangeCue(int textTrackUid, String id, int uid, double startTime, double endTime, String? cueClass, double startDateMillis, double? endDateMillis, double? duration, double? plannedDuration, bool endOnNext, String? customAttributesJson) → void
onTextTrackChange(int textTrackUid) → void
onTextTrackCueChange(int textTrackUid) → void
onTextTrackEnterCue(int textTrackUid, int cueUid) → void
onTextTrackExitCue(int textTrackUid, int cueUid) → void
onTextTrackListChange(int uid) → void
onTextTrackRemoveCue(int textTrackUid, int cueUid) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

setUp(THEOplayerFlutterTextTracksAPI? api, {BinaryMessenger? binaryMessenger, String messageChannelSuffix = ''}) → void

Constants

pigeonChannelCodec → const MessageCodec<Object?>