THEOliveInternalInterface class abstract
- Implemented types
- Implementers
Constructors
Properties
- badNetworkMode ↔ bool
-
getter/setter pair
-
currentLatency
→ Future<
double?> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
latencies
→ Future<
HespLatencies?> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addEventListener(
String eventType, EventListener< Event> listener) → void -
inherited
-
dispose(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
preloadChannels(
List< String> channelIDs) → void -
removeEventListener(
String eventType, EventListener< Event> listener) → void -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited