DateRangeCueImpl class

Inheritance

Constructors

DateRangeCueImpl(String id, int uid, double startTime, double _endTime, DateTime _startDate, DateTime? _endDate, double? _duration, double? _plannedDuration, String? _cueClass, bool _endOnNext, Map<String, dynamic>? _customAttributes)

Properties

content → dynamic
The content of the cue.
no setteroverride
cueClass String?
The class of the date range.
no setteroverride
customAttributes Map<String, dynamic>?
Custom attributes from the EXT-X-DATERANGE tag.
no setteroverride
duration double?
The duration of the date range in seconds, if available.
no setteroverride
endDate DateTime?
The end date of the date range, if available.
no setteroverride
endOnNext bool
Whether the date range ends on the next date range of the same class.
no setteroverride
endTime double
The playback position at which the cue becomes inactive, in seconds.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
id String
The identifier of the cue.
no setterinherited
plannedDuration double?
The planned duration of the date range in seconds, if available.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startDate DateTime
The start date of the date range.
no setteroverride
startTime double
The playback position at which the cue becomes active, in seconds.
no setterinherited
uid int
A unique identifier of the text track cue.
no setterinherited

Methods

addEventListener(String eventType, EventListener<Event> listener) → void
override
dispatchEvent(Event event) → void
dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeEventListener(String eventType, EventListener<Event> listener) → void
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited