SourceLatencyConfiguration class
The source-level latency configuration for live playback.
All offsets are expressed in seconds. On iOS, only targetOffset is supported.
Constructors
Properties
- forceSeekOffset ↔ double?
-
The offset above which the player seeks to live.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- maximumOffset ↔ double?
-
The offset above which the player speeds up.
getter/setter pair
- maximumPlaybackRate ↔ double?
-
The maximum playback rate used to decrease latency.
getter/setter pair
- minimumOffset ↔ double?
-
The offset below which the player slows down.
getter/setter pair
- minimumPlaybackRate ↔ double?
-
The minimum playback rate used to increase latency.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- targetOffset ↔ double
-
The live offset that the player aims for.
getter/setter pair
Methods
-
encode(
) → Object -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decode(
Object result) → SourceLatencyConfiguration